import app from '@system.app'
import fetch from '@system.fetch'
import request from '@system.request'
import prompt from '@system.prompt'
import storage from '@system.storage'
import url from './url.js'
import cache from './cache.js'

const key = {
    value: ''
}

function doRequest(obj) {
    obj.data = obj.data || {}
    obj.data.key = key.value
    console.log(`${obj.url} ? ${obj.data == {} ? '' : JSON.stringify(obj.data)}`);
    fetch.fetch({
        url: obj.url,
        data: obj.data,
        method: obj.method || 'GET',
        header: {
            "X-UA": "xcx_Android#" + app.getInfo().versionCode,
        },
        success: function (res) {
            if (res.code != 200) {
                console.log(`request exception code ${res.code}`)
                fail(obj, res.data)
                return
            }
            const data = JSON.parse(res.data)
            if (data.code == 601 || data.code == 10004) {
                //Server Key 失效
                console.log(`key invaild ${data.code}`)
                getKey(obj)
                return
            }
            if (data.code != 200) {
                console.log(`server exception code ${data.code}`)
                fail(obj, data.msg)
                return
            }
            console.log(`data: ${JSON.stringify(data)}`)
            success(obj, data)
        },
        fail: function (err, code) {
            console.log(`handling fail, code = ${err}`)
            fail(obj, err);
        },
        complete: function(){
            complete(obj)
        }
    })
}

function upload(obj){
    obj.data = obj.data || []
    if(obj.data.length > 0 && obj.data[obj.data.length - 1].name == 'key'){
        obj.data[obj.data.length - 1].value = key.value
    }else{
        obj.data.push({
            name: 'key',
            value: key.value
        })
    }
    console.log(`${obj.url} ? ${JSON.stringify(obj.data)}`);
    request.upload({
      url: obj.url,
      header: {
        "X-UA": "xcx_Android# " + app.getInfo().versionCode,
      },
      files: obj.files,
      data: obj.data,
      success: function (res) {
        if (res.code != 200) {
            console.log(`request exception code ${res.code}`)
            fail(obj, res.data)
            return
        }
        const data = JSON.parse(res.data)
        if (data.code == 601 || data.code == 10004) {
            //Server Key 失效
            console.log(`key invaild ${data.code}`)
            getKey(obj, 'upload')
            return
        }
        if (data.code != 200) {
            console.log(`server exception code ${data.code}`)
            fail(obj, data.msg)
            return
        }
        console.log(`data: ${JSON.stringify(data)}`)
        success(obj, data)
      },
      fail: function (err, code) {
        console.log(`handling fail, code = ${err}`)
        fail(obj, err);
      },
      complete: function () {
        complete(obj)
      }
    })
}

function get(obj) {
    obj.method = 'GET'
    doRequest(obj)
}

function post(obj) {
    obj.method = 'POST'
    doRequest(obj)
}

function success(obj, data) {
    if (obj.success instanceof Function) {
        obj.success(data)
    }
}

function complete(obj) {
    if (obj.complete instanceof Function) {
        obj.complete()
    }
}

function fail(obj, err) {
    if (obj.fail instanceof Function) {
        obj.fail(err)
    } else {
        prompt.showToast({
            message: err,
        })
    }
}

function getKey(obj, type){
    if(obj.isGetKeyEd){
        return
    }
    const that = this
    storage.get({
      key: cache.nUser,
      success: function (data) {
        if (data === "") {
            fail(obj, '请重新登录')
            return
        }
        obj.isGetKeyEd = true
        const user = JSON.parse(data)
        login({
            data: {
                phone: user.phone,
                password: user.password,
            },
            success: function(res){
                if(type == 'upload'){
                    upload(obj)
                }else{
                    doRequest(obj)
                }
            }
        })
      },
      fail: function (data, code) {
        fail(obj, '请重新登录')
      }
    })
}

function login(obj) {
    post({
        url: url.login,
        data: obj.data,
        success: function (res) {
            key.value = res.data.key
            const user = {
                id: res.data.uid,
                phone: obj.data.phone,
                password: obj.data.password,
                head_img: res.data.head_img
            }
            storage.set({
                key: cache.nUser,
                value: JSON.stringify(user)
            })
            const persons = JSON.stringify(res.data.userList)
            storage.set({
                key: cache.nPersons,
                value: persons
            })
            const result = {
                user: user,
                persons: res.data.userList
            }
            success(obj, result)
        },
        fail: function (err) {
            fail(obj, err)
        },
        complete: function () {
            complete(obj)
        }
    })
}

export default {
    key,
    get,
    post,
    upload,
    login
}