const phone = /^0?(13|14|15|16|17|18|19)[0-9]{9}$/
const pwd = /^[a-zA-Z0-9_]{6,18}$/
const name = /^[A-Za-z·\u4e00-\u9fa5]{1,16}$/
const nation = /^[\u4e00-\u9fa5]{1,6}$/
const vcode = /^[0-9]{4}$/
const bankName = /^[\u4e00-\u9fa5]{4,12}$/
const bankNumber = /^[0-9]{14,22}$/

function isPhone(target) {
    return phone.test(target)
}

function isPwd(target) {
    return pwd.test(target)
}

function isVCode(target) {
    return vcode.test(target)
}

function isRealName(target) {
    return name.test(target)
}

function isNation(target) {
    return nation.test(target)
}

function isBankName(target) {
    return bankName.test(target)
}

function isBankNumber(target) {
    return bankNumber.test(target)
}

function verify(reg, target) {
    return reg.test(target)
}

function isIdCard(code) {
    var city = {
        11: "北京",
        12: "天津",
        13: "河北",
        14: "山西",
        15: "内蒙古",
        21: "辽宁",
        22: "吉林",
        23: "黑龙江 ",
        31: "上海",
        32: "江苏",
        33: "浙江",
        34: "安徽",
        35: "福建",
        36: "江西",
        37: "山东",
        41: "河南",
        42: "湖北 ",
        43: "湖南",
        44: "广东",
        45: "广西",
        46: "海南",
        50: "重庆",
        51: "四川",
        52: "贵州",
        53: "云南",
        54: "西藏 ",
        61: "陕西",
        62: "甘肃",
        63: "青海",
        64: "宁夏",
        65: "新疆",
        71: "台湾",
        81: "香港",
        82: "澳门",
        91: "国外 "
    };
    var pass = true;

    if (!code || !/^\d{6}(18|19|20)?\d{2}(0[1-9]|1[012])(0[1-9]|[12]\d|3[01])\d{3}(\d|X)$/i.test(code)) {
        return false
    } else if (!city[code.substr(0, 2)]) {
        return false;
    } else {
        //18位身份证需要验证最后一位校验位
        if (code.length == 18) {
            code = code.split('');
            //∑(ai×Wi)(mod 11)
            //加权因子
            var factor = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
            //校验位
            var parity = [1, 0, 'X', 9, 8, 7, 6, 5, 4, 3, 2];
            var sum = 0;
            var ai = 0;
            var wi = 0;
            for (var i = 0; i < 17; i++) {
                ai = code[i];
                wi = factor[i];
                sum += ai * wi;
            }
            var last = parity[sum % 11];
            if (parity[sum % 11] != code[17]) {
                return false;
            }
        }
    }
    return true;
}

function isCanBuyByIdCard(card) {
    if (!card || card.length < 10) {
        return false
    }
    var nYear = new Date().getFullYear()
    var year = card.substring(6, 10)
    var offset = nYear - year
    if (offset >= 60) {
        return false
    } else {
        return true
    }
}

export default {
    isPhone,
    isPwd,
    isVCode,
    isRealName,
    isNation,
    isIdCard,
    isCanBuyByIdCard,
    isBankName,
    isBankNumber
}